@@ -1,21 +1,17 @@
 /*
-    Copyright 2005-2014 Intel Corporation.  All Rights Reserved.
+    Copyright (c) 2005-2019 Intel Corporation
 
-    This file is part of Threading Building Blocks. Threading Building Blocks is free software;
-    you can redistribute it and/or modify it under the terms of the GNU General Public License
-    version 2  as  published  by  the  Free Software Foundation.  Threading Building Blocks is
-    distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
-    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-    See  the GNU General Public License for more details.   You should have received a copy of
-    the  GNU General Public License along with Threading Building Blocks; if not, write to the
-    Free Software Foundation, Inc.,  51 Franklin St,  Fifth Floor,  Boston,  MA 02110-1301 USA
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    As a special exception,  you may use this file  as part of a free software library without
-    restriction.  Specifically,  if other files instantiate templates  or use macros or inline
-    functions from this file, or you compile this file and link it with other files to produce
-    an executable,  this file does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however invalidate any other
-    reasons why the executable file might be covered by the GNU General Public License.
+        http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 */
 
 // Do not include task.h directly. Use scheduler_common.h instead
@@ -31,15 +27,13 @@
 
 namespace tbb {
 
-using namespace std;
-
 namespace internal {
 
 //------------------------------------------------------------------------
 // Methods of allocate_root_proxy
 //------------------------------------------------------------------------
 task& allocate_root_proxy::allocate( size_t size ) {
-    internal::generic_scheduler* v = governor::local_scheduler();
+    internal::generic_scheduler* v = governor::local_scheduler_weak();
     __TBB_ASSERT( v, "thread did not activate a task_scheduler_init object?" );
 #if __TBB_TASK_GROUP_CONTEXT
     task_prefix& p = v->my_innermost_running_task->prefix();
@@ -51,7 +45,7 @@ task& allocate_root_proxy::allocate( size_t size ) {
 }
 
 void allocate_root_proxy::free( task& task ) {
-    internal::generic_scheduler* v = governor::local_scheduler();
+    internal::generic_scheduler* v = governor::local_scheduler_weak();
     __TBB_ASSERT( v, "thread does not have initialized task_scheduler_init object?" );
 #if __TBB_TASK_GROUP_CONTEXT
     // No need to do anything here as long as there is no context -> task connection
@@ -64,8 +58,9 @@ void allocate_root_proxy::free( task& task ) {
 // Methods of allocate_root_with_context_proxy
 //------------------------------------------------------------------------
 task& allocate_root_with_context_proxy::allocate( size_t size ) const {
-    internal::generic_scheduler* s = governor::local_scheduler();
+    internal::generic_scheduler* s = governor::local_scheduler_weak();
     __TBB_ASSERT( s, "Scheduler auto-initialization failed?" );
+    __TBB_ASSERT( &my_context, "allocate_root(context) argument is a dereferenced NULL pointer" );
     task& t = s->allocate_task( size, NULL, &my_context );
     // Supported usage model prohibits concurrent initial binding. Thus we do not
     // need interlocked operations or fences to manipulate with my_context.my_kind
@@ -73,7 +68,7 @@ task& allocate_root_with_context_proxy::allocate( size_t size ) const {
         // If we are in the outermost task dispatch loop of a master thread, then
         // there is nothing to bind this context to, and we skip the binding part
         // treating the context as isolated.
-        if ( s->my_innermost_running_task == s->my_dummy_task )
+        if ( s->master_outermost_level() )
             __TBB_store_relaxed(my_context.my_kind, task_group_context::isolated);
         else
             my_context.bind_to( s );
@@ -81,14 +76,14 @@ task& allocate_root_with_context_proxy::allocate( size_t size ) const {
 #if __TBB_FP_CONTEXT
     if ( __TBB_load_relaxed(my_context.my_kind) == task_group_context::isolated &&
             !(my_context.my_version_and_traits & task_group_context::fp_settings) )
-        my_context.copy_fp_settings( *s->my_arena->my_default_ctx );
+        my_context.copy_fp_settings( *s->default_context() );
 #endif
     ITT_STACK_CREATE(my_context.itt_caller);
     return t;
 }
 
 void allocate_root_with_context_proxy::free( task& task ) const {
-    internal::generic_scheduler* v = governor::local_scheduler();
+    internal::generic_scheduler* v = governor::local_scheduler_weak();
     __TBB_ASSERT( v, "thread does not have initialized task_scheduler_init object?" );
     // No need to do anything here as long as unbinding is performed by context destructor only.
     v->free_task<local_task>( task );
@@ -99,32 +94,32 @@ void allocate_root_with_context_proxy::free( task& task ) const {
 // Methods of allocate_continuation_proxy
 //------------------------------------------------------------------------
 task& allocate_continuation_proxy::allocate( size_t size ) const {
-    task& t = *((task*)this);
+    task* t = (task*)this;
     assert_task_valid(t);
-    generic_scheduler* s = governor::local_scheduler();
-    task* parent = t.parent();
-    t.prefix().parent = NULL;
-    return s->allocate_task( size, __TBB_CONTEXT_ARG(parent, t.prefix().context) );
+    generic_scheduler* s = governor::local_scheduler_weak();
+    task* parent = t->parent();
+    t->prefix().parent = NULL;
+    return s->allocate_task( size, __TBB_CONTEXT_ARG(parent, t->prefix().context) );
 }
 
 void allocate_continuation_proxy::free( task& mytask ) const {
     // Restore the parent as it was before the corresponding allocate was called.
     ((task*)this)->prefix().parent = mytask.parent();
-    governor::local_scheduler()->free_task<local_task>(mytask);
+    governor::local_scheduler_weak()->free_task<local_task>(mytask);
 }
 
 //------------------------------------------------------------------------
 // Methods of allocate_child_proxy
 //------------------------------------------------------------------------
 task& allocate_child_proxy::allocate( size_t size ) const {
-    task& t = *((task*)this);
+    task* t = (task*)this;
     assert_task_valid(t);
-    generic_scheduler* s = governor::local_scheduler();
-    return s->allocate_task( size, __TBB_CONTEXT_ARG(&t, t.prefix().context) );
+    generic_scheduler* s = governor::local_scheduler_weak();
+    return s->allocate_task( size, __TBB_CONTEXT_ARG(t, t->prefix().context) );
 }
 
 void allocate_child_proxy::free( task& mytask ) const {
-    governor::local_scheduler()->free_task<local_task>(mytask);
+    governor::local_scheduler_weak()->free_task<local_task>(mytask);
 }
 
 //------------------------------------------------------------------------
@@ -132,7 +127,7 @@ void allocate_child_proxy::free( task& mytask ) const {
 //------------------------------------------------------------------------
 task& allocate_additional_child_of_proxy::allocate( size_t size ) const {
     parent.increment_ref_count();
-    generic_scheduler* s = governor::local_scheduler();
+    generic_scheduler* s = governor::local_scheduler_weak();
     return s->allocate_task( size, __TBB_CONTEXT_ARG(&parent, parent.prefix().context) );
 }
 
@@ -145,7 +140,7 @@ void allocate_additional_child_of_proxy::free( task& task ) const {
     // reference count might have become zero before the corresponding call to
     // allocate_additional_child_of_proxy::allocate.
     parent.internal_decrement_ref_count();
-    governor::local_scheduler()->free_task<local_task>(task);
+    governor::local_scheduler_weak()->free_task<local_task>(task);
 }
 
 //------------------------------------------------------------------------
@@ -153,7 +148,7 @@ void allocate_additional_child_of_proxy::free( task& task ) const {
 //------------------------------------------------------------------------
 size_t get_initial_auto_partitioner_divisor() {
     const size_t X_FACTOR = 4;
-    return X_FACTOR * (1+governor::local_scheduler()->number_of_workers_in_my_arena());
+    return X_FACTOR * governor::local_scheduler()->max_threads_in_arena();
 }
 
 //------------------------------------------------------------------------
@@ -161,7 +156,7 @@ size_t get_initial_auto_partitioner_divisor() {
 //------------------------------------------------------------------------
 void affinity_partitioner_base_v3::resize( unsigned factor ) {
     // Check factor to avoid asking for number of workers while there might be no arena.
-    size_t new_size = factor ? factor*(1+governor::local_scheduler()->number_of_workers_in_my_arena()) : 0;
+    size_t new_size = factor ? factor*governor::local_scheduler()->max_threads_in_arena() : 0;
     if( new_size!=my_size ) {
         if( my_array ) {
             NFS_Free( my_array );
@@ -171,7 +166,7 @@ void affinity_partitioner_base_v3::resize( unsigned factor ) {
         }
         if( new_size ) {
             my_array = static_cast<affinity_id*>(NFS_Allocate(new_size,sizeof(affinity_id), NULL ));
-            memset( my_array, 0, sizeof(affinity_id)*new_size );
+            memset( static_cast<void*>(my_array), 0, sizeof(affinity_id)*new_size );
             my_size = new_size;
         }
     }
@@ -204,7 +199,7 @@ internal::reference_count task::internal_decrement_ref_count() {
 }
 
 task& task::self() {
-    generic_scheduler *v = governor::local_scheduler();
+    generic_scheduler *v = governor::local_scheduler_weak();
     v->assert_task_pool_valid();
     __TBB_ASSERT( v->my_innermost_running_task, NULL );
     return *v->my_innermost_running_task;
@@ -230,7 +225,7 @@ void interface5::internal::task_base::destroy( task& victim ) {
         parent->internal_decrement_ref_count();
         // Even if the last reference to *parent is removed, it should not be spawned (documented behavior).
     }
-    governor::local_scheduler()->free_task<no_cache>( victim );
+    governor::local_scheduler_weak()->free_task<no_cache>( victim );
 }
 
 void task::spawn_and_wait_for_all( task_list& list ) {
@@ -238,7 +233,7 @@ void task::spawn_and_wait_for_all( task_list& list ) {
     task* t = list.first;
     if( t ) {
         if( &t->prefix().next!=list.next_ptr )
-            s->local_spawn( *t->prefix().next, *list.next_ptr );
+            s->local_spawn( t->prefix().next, *list.next_ptr );
         list.clear();
     }
     s->local_wait_for_all( *this, t );
@@ -253,12 +248,12 @@ void task::note_affinity( affinity_id ) {
 #if __TBB_TASK_GROUP_CONTEXT
 void task::change_group ( task_group_context& ctx ) {
     prefix().context = &ctx;
-    internal::generic_scheduler* s = governor::local_scheduler();
+    internal::generic_scheduler* s = governor::local_scheduler_weak();
     if ( __TBB_load_relaxed(ctx.my_kind) == task_group_context::binding_required ) {
         // If we are in the outermost task dispatch loop of a master thread, then
         // there is nothing to bind this context to, and we skip the binding part
         // treating the context as isolated.
-        if ( s->my_innermost_running_task == s->my_dummy_task )
+        if ( s->master_outermost_level() )
             __TBB_store_relaxed(ctx.my_kind, task_group_context::isolated);
         else
             ctx.bind_to( s );
@@ -266,7 +261,7 @@ void task::change_group ( task_group_context& ctx ) {
 #if __TBB_FP_CONTEXT
     if ( __TBB_load_relaxed(ctx.my_kind) == task_group_context::isolated &&
             !(ctx.my_version_and_traits & task_group_context::fp_settings) )
-        ctx.copy_fp_settings( *s->my_arena->my_default_ctx );
+        ctx.copy_fp_settings( *s->default_context() );
 #endif
     ITT_STACK_CREATE(ctx.itt_caller);
 }
